(***********************************************************************)
(*  v      *   The Coq Proof Assistant  /  The Coq Development Team    *)
(* <O___,, *        INRIA-Rocquencourt  &  LRI-CNRS-Orsay              *)
(*   \VV/  *************************************************************)
(*    //   *      This file is distributed under the terms of the      *)
(*         *       GNU Lesser General Public License Version 2.1       *)
(***********************************************************************)

(*i $Id: haskell.mli,v 1.10 2002/04/08 12:25:11 letouzey Exp $ i*)

open Pp
open Names
open Nametab
open Miniml

val keywords : Idset.t

val preamble : extraction_params -> Idset.t -> bool -> std_ppcmds

module Make : functor(P : Mlpp_param) -> Mlpp
